@@ -331,15 +331,22 @@ tree_hulls = function(las, type = c("convex", "concave", "bbox"), concavity = 3,
   return(delineate_crowns(las, type, concavity, length_threshold, func, attribute))
 }
 
+#' @export
+#' @rdname deprecated
+hexbin_metrics = function(...)
+{
+  stop("hexbin_metrics() was an unused function and has been removed from lidR. It can be retrieved in lidRplugins https://github.com/Jean-Romain/lidRplugins")
+}
+
 .lidr3depreciation <- function(name)
 {
   # no depreciation v3.0.0
   #return(invisible())
 
-  # message v 3.1.0
-  msg = paste(as.character(sys.call(sys.parent()))[1L], "is deprecated. Use", name, "instead.")
-  message(msg)
-  return(invisible())
+  # message v3.1.0
+  #msg = paste(as.character(sys.call(sys.parent()))[1L], "is deprecated. Use", name, "instead.")
+  #message(msg)
+  #return(invisible())
 
   # warning v3.2.0
   msg = paste(as.character(sys.call(sys.parent()))[1L], "is deprecated. Use", name, "instead.")
@@ -352,4 +359,6 @@ tree_hulls = function(las, type = c("convex", "concave", "bbox"), concavity = 3,
   return(invisible())
 }
 
+
+
 # nocov end
