@@ -102,20 +102,17 @@ voxel_metrics = function(las, func, res = 1, ..., all_voxels = FALSE)
 
   if (all_voxels)
   {
-    xrange <- range(las$X)
-    yrange <- range(las$Y)
-    zrange <- range(las$Z)
-    xrange <- f_grid(xrange, res[1], 0)
-    yrange <- f_grid(yrange, res[1], 0)
-    zrange <- f_grid(zrange, res[2], 0.5*res[2])
-    X <- seq(xrange[1], xrange[2], by = res[1])
-    Y <- seq(yrange[1], yrange[2], by = res[1])
-    Z <- seq(zrange[1], zrange[2], by = res[2])
+    xrange <- range(stat$X)
+    yrange <- range(stat$Y)
+    zrange <- range(stat$Z)
+    X <- f_grid(seq(xrange[1], xrange[2], by = res[1]), res[1], 0)
+    Y <- f_grid(seq(yrange[1], yrange[2], by = res[1]), res[1], 0)
+    Z <- f_grid(seq(zrange[1], zrange[2], by = res[2]), res[2], 0.5*res[2])
     all <- expand.grid(X = X,Y = Y, Z = Z)
     data.table::setDT(all)
-    data.table::setkey(all, X,Y, Z)
-    data.table::setkey(stat, X,Y, Z)
-    stat <- stat[all]
+    data.table::setkey(all, X,Y,Z)
+    data.table::setkey(stat, X,Y,Z)
+    stat <- merge(stat, all, all = TRUE)
   }
 
   data.table::setattr(stat, "class", c("lasmetrics3d", attr(stat, "class")))
